@@ -72,9 +72,11 @@ _mongoc_socket_capture_errno (mongoc_socket_t *sock) /* IN */
 /*
  *--------------------------------------------------------------------------
  *
- * _mongoc_socket_setnonblock --
+ * _mongoc_socket_setflags --
+ *
+ *       A helper to set socket flags. Sets to nonblocking mode. On
+ *       POSIX sets closeonexec.
  *
- *       A helper to set a socket in nonblocking mode.
  *
  * Returns:
  *       true if successful; otherwise false.
@@ -87,9 +89,9 @@ _mongoc_socket_capture_errno (mongoc_socket_t *sock) /* IN */
 
 static bool
 #ifdef _WIN32
-_mongoc_socket_setnonblock (SOCKET sd)
+_mongoc_socket_setflags (SOCKET sd)
 #else
-_mongoc_socket_setnonblock (int sd)
+_mongoc_socket_setflags (int sd)
 #endif
 {
 #ifdef _WIN32
@@ -98,8 +100,19 @@ _mongoc_socket_setnonblock (int sd)
 #else
    int flags;
 
-   flags = fcntl (sd, F_GETFL, sd);
-   return (-1 != fcntl (sd, F_SETFL, (flags | O_NONBLOCK)));
+   flags = fcntl (sd, F_GETFL);
+
+   if (-1 == fcntl (sd, F_SETFL, (flags | O_NONBLOCK))) {
+      return false;
+   }
+
+#ifdef FD_CLOEXEC
+   flags = fcntl (sd, F_GETFD);
+   if (-1 == fcntl (sd, F_SETFD, (flags | FD_CLOEXEC))) {
+      return false;
+   }
+#endif
+   return true;
 #endif
 }
 
@@ -217,9 +230,7 @@ _mongoc_socket_wait (mongoc_socket_t *sock, /* IN */
 
          TRACE ("errno is: %d", errno);
          if (MONGOC_ERRNO_IS_AGAIN (errno)) {
-            now = bson_get_monotonic_time ();
-
-            if (expire_at < now) {
+            if (OPERATION_EXPIRED (expire_at)) {
                _mongoc_socket_capture_errno (sock);
                RETURN (false);
             } else {
@@ -348,7 +359,7 @@ mongoc_socket_poll (mongoc_socket_poll_t *sds, /* IN */
 
 /* https://jira.mongodb.org/browse/CDRIVER-2176 */
 #define MONGODB_KEEPALIVEINTVL 10
-#define MONGODB_KEEPIDLE 300
+#define MONGODB_KEEPIDLE 120
 #define MONGODB_KEEPALIVECNT 9
 
 #ifdef _WIN32
@@ -426,7 +437,7 @@ _mongoc_socket_setkeepalive_windows (SOCKET sd)
    }
 }
 #else
-#ifdef MONGOC_TRACE
+
 static const char *
 _mongoc_socket_sockopt_value_to_name (int value)
 {
@@ -452,7 +463,7 @@ _mongoc_socket_sockopt_value_to_name (int value)
       return "Unknown option name";
    }
 }
-#endif
+
 static void
 _mongoc_socket_set_sockopt_if_less (int sd, int name, int value)
 {
@@ -704,7 +715,7 @@ again:
       RETURN (NULL);
    } else if (failed) {
       RETURN (NULL);
-   } else if (!_mongoc_socket_setnonblock (sd)) {
+   } else if (!_mongoc_socket_setflags (sd)) {
 #ifdef _WIN32
       closesocket (sd);
 #else
@@ -982,6 +993,9 @@ mongoc_socket_new (int domain,   /* IN */
 #else
    int sd;
 #endif
+#ifdef SO_NOSIGPIPE
+   int on = 1;
+#endif
 
    ENTRY;
 
@@ -995,7 +1009,7 @@ mongoc_socket_new (int domain,   /* IN */
       RETURN (NULL);
    }
 
-   if (!_mongoc_socket_setnonblock (sd)) {
+   if (!_mongoc_socket_setflags (sd)) {
       GOTO (fail);
    }
 
@@ -1006,6 +1020,12 @@ mongoc_socket_new (int domain,   /* IN */
       _mongoc_socket_setkeepalive (sd);
    }
 
+   /* Set SO_NOSIGPIPE, to ignore SIGPIPE on writes for platforms where
+      setting MSG_NOSIGNAL on writes is not supported (primarily OSX). */
+#ifdef SO_NOSIGPIPE
+   setsockopt(sd, SOL_SOCKET, SO_NOSIGPIPE, &on, sizeof(on));
+#endif
+
    sock = (mongoc_socket_t *) bson_malloc0 (sizeof *sock);
    sock->sd = sd;
    sock->domain = domain;
